@@ -11,6 +11,56 @@ from pyf.splitter.inputsplitter import input_item_separator, tokenize,\
 import re
 
 class Packet(object):
+    """ A packet is a dictionnary-like object that is easily serializable to
+    simple dictionnaries with base data types.
+    
+    Its members can be accessed either with attributes or items::
+    
+        >>> my_packet.foo = 'bar'
+        >>> my_packet.foo == my_packet['foo']
+        True
+        
+        >>> my_packet['foo'] == 'bar'
+        True
+    
+    It takes an optionnal dictionnary as argument for initialization, to have its
+    data set as the initialization data for the packet (if data_type is set to "simple")::
+        
+        >>> my_packet = Packet(dict(foo="bar"))
+        >>> my_packet['foo'] == 'bar'
+        True
+    
+    To serialize, deserialize it, just access the serialized argument::
+        
+        >>> my_packet.serialized
+        {'foo': {'metadata': {'compound': False,
+                      'multi_values': False,
+                      'type': 'string'},
+         'value': 'bar'}}
+        
+        >>> import datetime
+        >>> my_complex_packet = Packet(dict(now=datetime.datetime.now(),
+        ...                                 test='bar'))
+        
+        >>> my_complex_packet
+        {'test': 'bar', 'now': datetime.datetime(2010, 12, 16, 12, 23, 47, 259568)}
+        
+        >>> my_complex_packet.serialized
+        {'now': {'metadata': {'compound': False,
+                              'multi_values': False,
+                              'type': 'datetime'},
+                 'value': '2010-12-16T12:23:47.259568'},
+         'test': {'metadata': {'compound': False,
+                               'multi_values': False,
+                               'type': 'string'},
+                  'value': 'bar'}}
+        >>> my_new_packet = Packet(data=my_complex_packet.serialized, data_type="serialized")
+        >>> my_new_packet.now
+        datetime.datetime(2010, 12, 16, 12, 23, 47)
+        >>> my_complex_packet.test
+        'bar'
+    """
+    
     def __init__(self, data=None, data_type="simple"):
         super(Packet, self).__init__()
         
@@ -142,6 +192,12 @@ class Packet(object):
     def __delitem__(self, key):
         del self.__data['key']
         
+    def __getstate__(self):
+        return self.serialized
+    
+    def __setstate__(self, dictobj):
+        self.__data = self.unserialize_data_dict(dictobj)
+        
     def set_metadata(self, field, key, value):
         self.__data[field]['metadata'][key] = value
         
@@ -242,6 +298,8 @@ def encode_packet_flow(object_flow,
                        separator=input_item_separator,
                        iterencode=False,
                        compress=False):
+    """ Encodes a packet flow to a bytestring flow of json serialized packets.
+    """
     encoder = PacketEncoder()
     for obj in object_flow:
         if iterencode:
@@ -266,6 +324,13 @@ def decode_packet_flow(source, buffersize=16384,
                        separator=input_item_separator,
                        decompress=False,
                        pure_flow=False):
+    """Decodes a packet flow from a source.
+    
+    If pure_flow is set to False (default), the source is either a file-like of a iterator over strings containing the sepator.
+    If pure_flow is True, the source is a generator containing strings without the separator.
+    
+    If decompress is set to True, the data is decompressed using zlib.
+    """
     buffer = ""
     
     newdata = "dummy"
